Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2713)

Unified Diff: chrome/browser/predictors/resource_prefetcher_manager.h

Issue 2377643002: predictors: Make the resource_prefetch_predictor accessible from Java. (Closed)
Patch Set: Address comments. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/predictors/resource_prefetcher_manager.h
diff --git a/chrome/browser/predictors/resource_prefetcher_manager.h b/chrome/browser/predictors/resource_prefetcher_manager.h
index 73d3913329ca8d2af1659b774eba440cb4812c79..10bf889a491797fc57d5309f2ed5fbbc046f8129 100644
--- a/chrome/browser/predictors/resource_prefetcher_manager.h
+++ b/chrome/browser/predictors/resource_prefetcher_manager.h
@@ -7,6 +7,8 @@
#include <map>
#include <memory>
+#include <string>
+#include <vector>
#include "base/macros.h"
#include "base/memory/ref_counted.h"
@@ -44,14 +46,14 @@ class ResourcePrefetcherManager
// The prefetchers need to be deleted on the IO thread.
void ShutdownOnIOThread();
- // Will create a new ResourcePrefetcher for the main frame url of the input
- // navigation if there isn't one already for the same host.
- void MaybeAddPrefetch(const NavigationID& navigation_id,
+ // Will create a new ResourcePrefetcher for a given main frame url if there
+ // isn't one already for the same host.
+ void MaybeAddPrefetch(const GURL& main_frame_url,
const std::vector<GURL>& urls);
// Stops the ResourcePrefetcher for the input navigation, if one was in
// progress.
- void MaybeRemovePrefetch(const NavigationID& navigation_id);
+ void MaybeRemovePrefetch(const GURL& main_frame_url);
// ResourcePrefetcher::Delegate methods.
void ResourcePrefetcherFinished(ResourcePrefetcher* prefetcher) override;
@@ -44,14 +46,14 @@ class ResourcePrefetcherManager
const std::vector<GURL>& urls);
- // Stops the ResourcePrefetcher for the input navigation, if one was in
+ // Stops the ResourcePrefetcher for a given main frame URL, if one was in
// progress.

Powered by Google App Engine
This is Rietveld 408576698